/** \file LatexTabellenLogger.h
 * @brief Deklaration der LatexTabellenLogger-Klasse.
 *  Created on: 28.01.2009
 *  Author: Rdiger Knrig
 */

#ifndef LATEXTABELLENLOGGER_H_
#define LATEXTABELLENLOGGER_H_

#include <string>
#include <stdexcept>
#include <fstream>
#include <iostream>

using namespace std;

/**
 * @brief Klasse zur Aufzeichnung von Werten als LaTeX-Tabelle.
 * @author Rdiger Knrig
 *
 */
class LatexTabellenLogger
{
public:
	/**
	 * @brief Konstruktor.
	 * @param Dateiname  Dateiname der Ausgabedatei / filename of the output file.
	 * @param Spalten  Anzahl an Spalten in der Tabelle.
	 * @param ExpSchr Werte betragsmig grer als \f$10^{ExpSchr}\f$ oder kleiner als \f$10^{-ExpSchr}\f$ werden im Exponentialschreibweise geschrieben.
	 * @param localestr C++-Locale fr die Textausgabe (Nummernformat etc.)
	 * @throws runtime_error-Exception bei einem fatalen Fehler (Dateioperationen etc.)
	 */
	LatexTabellenLogger(const string &Dateiname,unsigned int Spalten,unsigned int ExpSchr=3,const char *localestr="german") throw(std::runtime_error);

	/**
	 * @brief Destruktor.
	 */
	~LatexTabellenLogger();

	/**
	 * @brief Setzt die Tabellenbeschriftung / setter for the caption.
	 */
	void setzeBeschriftung(const string &beschr) { caption = beschr; }

	/**
	 * @brief Setzt die Tabellenbezeichnung / setter for the label.
	 */
	void setzeBezeichnung(const string &bezeichnung) { label = bezeichnung; }


	/**
	 * @brief Ausgabeoperator fr Zeichenketten.
	 * @param wert Zeichenkette zur Ausgabe in der Tabelle.
	 */
	LatexTabellenLogger &operator<<(string wert);

	/**
	 * @brief Ausgabeoperator fr double-Werte.
	 * @param wert Double-Wert zur Ausgabe in der Tabelle.
	 */
	LatexTabellenLogger &operator<<(double wert) { return LatexTabellenLogger::operator<<((long double) wert); }

	/**
	 * @brief Ausgabeoperator fr double-Werte.
	 * @param wert Double-Wert zur Ausgabe in der Tabelle.
	 */
	LatexTabellenLogger &operator<<(long double wert);

	/**
	 * @brief Ausgabeoperator fr float-Werte.
	 * @param wert Double-Wert zur Ausgabe in der Tabelle.
	 */
	LatexTabellenLogger &operator<<(float wert) { return LatexTabellenLogger::operator<<((long double) wert); }

	/**
	 * @brief Ausgabeoperator fr int-Werte.
	 * @param wert Double-Wert zur Ausgabe in der Tabelle.
	 */
	LatexTabellenLogger &operator<<(int wert);

	/**
	 * @brief Ausgabeoperator fr double-Werte.
	 * @param wert Double-Wert zur Ausgabe in der Tabelle.
	 */
	LatexTabellenLogger &operator<<(unsigned int wert);

protected:
	string caption; /**< Tabellenbeschriftung */
	string label; /**< Tabellenbezeichnung */
	ofstream ausgabe; /**< Ausgabestrom */
	unsigned int spalten; /**< Anzahl an Spalten / number of columns */
	unsigned int akt_sp; /**< Ausgabespaltenzhler / counter for the column position */
	bool header_geschr; /**< wahr wenn der Tabellenkopf schon geschrieben wurde */
	long double minv; /**< untere Schranke fr den Betrag, ab der Exponentialschreibweise angewendet wird */
	long double maxv; /**< obere Schranke fr den Betrag, ab der Exponentialschreibweise angewendet wird */
};

/** \example main.cpp
 * Beispielanwendung fr diese Klasse.
 */

/*! \mainpage Hauptseite
 *
 * \section intro_sec Einfhrung
 * Die Klasse LatexTabellenLogger ermglicht die bequeme Protokollierung von Daten
 * in Form von LaTeX-Tabellen.
 */

#endif /* LATEXTABELLENLOGGER_H_ */
